.. _internals:

Internals
=========

.. warning::
   The internals of pymech are described here for development purposes and is
   not part of the public API.

.. automodule:: pymech.log


:mod:`pymech.dataset`
---------------------

.. automodule:: pymech.dataset
   :noindex:
   :no-members:
   :private-members:  can_open_nek_dataset, _open_nek_dataset, _NekDataStore, PymechXarrayBackend

